import netapi from './netapi';
import Axios from 'axios';
import JSONbig from 'json-bigint';
import { projectconfig } from "../static/projectconfig"
import store from '../store/index'
import { Store } from 'le5le-store';

//const URL = '/api/';
const URL = process.env.VUE_APP_BASE_URL || '/wisdom-water/';
//******************************用户接口************************************//
export const loginRequest = objData =>
{
    return Axios.post(URL + "sys/login", objData);
};
export const registerUserRequest = objData =>
{
    return Axios.post(URL + "user/register", objData);
};
export const editUserRequest = objData =>
{
    return Axios.post(URL + "user/edit", objData);
};

export const getAllUserRequest = objData =>
{
    return Axios.post(URL + "user/get", objData, {
        headers: {
            'content-type': 'application/json',
            'token': objData.token
        }
    });

};
export const resetUserRequest = objData =>
{

    return Axios.post(URL + "/user/reset", objData, {
        headers: {
            'content-type': 'application/json',
            'token': objData.token
        }
    });
};


//******************************end****************************************//


//******************************公用接口************************************//

//根据场站编号，风机型号获取AI测点
export const fetchAIPointList = (stationId, modelId) =>
{
    return netapi({
        url: URL + 'info/testing_point_ai',
        method: 'get',
        params: {
            stationId: stationId,
            modelId: modelId
        },
        headers: {
            'content-type': 'application/json',
            'token': localStorage.getItem('token')
        },
    });
};
//根据场站编号，风机型号获取DI测点
export const fetchDIPointList = (stationId, modelId) =>
{
    return netapi({
        url: URL + 'info/testing_point_di',
        method: 'get',
        params: {
            stationId: stationId,
            modelId: modelId
        },
        headers: {
            'content-type': 'application/json',
            'token': localStorage.getItem('token')
        },
    });
};
//根据场站编号，获取电气DI测点
export const fetchElectricDIPointList = (stationId) =>
{
    return netapi({
        url: URL + 'info/electrical_point_di',
        method: 'get',
        params: {
            stationId: stationId
        }
    });
};
//根据电气测点，获取测点信息
export const fetchElectricDIPointByPointId = (pointId) =>
{
    return netapi({
        url: URL + 'info/electrical_point_di/byId',
        method: 'get',
        params: {
            pointId: pointId
        }
    });
};


//******************************end****************************************//


//******************************自定义报警API************************************//
export const alert_rule_fetchTableData = query =>
{
    let data =
        netapi({
            url: URL + 'rule/list',
            method: 'get',
            params: query,
            headers: {
                'content-type': 'application/json',
                'token': localStorage.getItem('token')
            },
            timeout: 3000,
        });
    return data;
};


export const alert_rule_postSave = form =>
{
    return Axios.post(URL + "alertrule2/save", form, {
        headers: {
            'content-type': 'application/json',
            'token': sessionStorage.getItem('token')
        }
    })
};


//******************************end*******************************************//


//#region  监视页面相关
export const monitor = {

    /*** 加载头文件导航中的监视页面的结构Json文件 */
    async getJsonFile()
    {
        await Axios.get
            (
                projectconfig.restful.host + projectconfig.restful.watcher,
                {
                    params:
                    {
                        keys: '/'
                    },
                    headers: {
                        'content-type': 'application/json',
                        'token': localStorage.getItem('token')
                    }
                }
            )
            .then(res =>
            {
                if (res.data && res.data.success && res.data.success == true && res.data.data && res.data.data.pagejson) {

                    var x = JSON.parse(res.data.data.pagejson);
                    store.dispatch('setPathSummary', x)
                }
            })
            .catch(error =>
            {
                console.log("getJsonFile 异常:" + error);
            });

    },
    async getJsonFileBy(path, callBack)
    {
        await Axios.get
            (
                projectconfig.restful.host + projectconfig.restful.watcher,
                {
                    params:
                    {
                        keys: path
                    },
                    headers: {
                        'content-type': 'application/json',
                        'token': localStorage.getItem('token')
                    }
                }
            )
            .then(res => callBack(res))
            .catch(error =>
            {
                console.log("getJsonFileBy 异常:" + error);
            });

    },
    async setJsonFile(monitorJson, backCall)
    {
        await Axios.post
            (
                projectconfig.restful.host + projectconfig.restful.postjson,
                monitorJson,
                {
                    headers: {
                        'content-type': 'application/json',
                        'token': localStorage.getItem('token')
                    }
                }
            ).then(res =>
            {
                if (backCall) {
                    backCall(res);
                }
                else {
                    //console.log(res.data)
                }
            }).catch(error =>
            {
                console.log("setJsonFile 异常:" + error);
                databack = error;
            });
    },
	/**
	 * 根据标签点名查询对应的数据
	 * @param {*} tagNameArray []
	 */
    getTagValues(tagNameArray)
    {
        Axios.get
            (
                projectconfig.restful.host + projectconfig.restful.searchTagValues,
                {
                    params:
                    {
                        keys: tagNameArray.join(',')
                    }
                }
            ).then(res =>
            {
                Store.set('wxwData', res.data);
            }).catch(error =>
            {
                //console.log("getTagValues 异常:" + error);
            });
    }

}

//#endregion